@@ -4,9 +4,9 @@
   .tabr_env$opts <- list(dev = "pdf", midi = TRUE)
   x <- c("lilypond", "midi2ly.py", "python")
   win_paths <- c("C:/Program Files (x86)/LilyPond/usr/bin", "C:/Program Files/LilyPond/usr/bin")
-  lp_path <- Sys.which(x[1])
-  ml_path <- Sys.which(x[2])
-  py_path <- Sys.which(x[3])
+  lp_path <- as.character(Sys.which(x[1]))
+  ml_path <- as.character(Sys.which(x[2]))
+  py_path <- as.character(Sys.which(x[3]))
   is_win <- .Platform$OS.type == "windows"
   if(is_win){
     if(lp_path == ""){
@@ -24,6 +24,11 @@
       if(file.exists(opts[1])) py_path <- opts[1]
       if(file.exists(opts[2])) py_path <- opts[2]
     }
+  } else {
+    if(lp_path != "" & ml_path == ""){
+      ml_path2 <- gsub("lilypond", "midi2ly.py", ml_path)
+      if(file.exists(ml_path2)) ml_path <- ml_path2
+    }
   }
   tabr_options(lilypond = lp_path, midi2ly = ml_path, python = py_path)
 }
