@@ -1,10 +1,15 @@
 ## ----setup, include = FALSE----------------------------------------------
+options(crayon.enabled = TRUE)
+sgr_wrap <- function(x, options){
+  paste0("<pre class=\"r-output\"><code>", fansi::sgr_to_html(x = htmltools::htmlEscape(x)), "</code></pre>")
+}
+knitr::knit_hooks$set(output = sgr_wrap)
 knitr::opts_chunk$set(
   collapse = TRUE, comment = "#>", message = FALSE, warning = FALSE, error = FALSE, tidy = FALSE, out.width = "100%"
 )
+library(tabr)
 
 ## ----p1------------------------------------------------------------------
-library(tabr)
 phrase(notes = "r a2 c3 f3 d3 a3 f3", info = "4 8 8 8 8 8 8", string = "x 5 5 4 4 3 4")
 
 ## ----p2------------------------------------------------------------------
@@ -45,5 +50,5 @@ cat(
 
 ## ----pipe, results="hide", eval=FALSE------------------------------------
 #  p("r a2 c f d a f", "4 8*6") %>% track %>% score %>%
-#    tab(song, "phrase.pdf", key = "dm", time = "4/4", tempo = "4 = 120")
+#    tab("phrase.pdf", key = "dm", time = "4/4", tempo = "4 = 120")
 
